summaryrefslogtreecommitdiff
path: root/source3/nsswitch/winbindd_dual.c
diff options
context:
space:
mode:
Diffstat (limited to 'source3/nsswitch/winbindd_dual.c')
-rw-r--r--source3/nsswitch/winbindd_dual.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/source3/nsswitch/winbindd_dual.c b/source3/nsswitch/winbindd_dual.c
index c6cafe79ec..b79445ee86 100644
--- a/source3/nsswitch/winbindd_dual.c
+++ b/source3/nsswitch/winbindd_dual.c
@@ -579,9 +579,9 @@ void winbind_msg_offline(struct messaging_context *msg_ctx,
}
for (child = children; child != NULL; child = child->next) {
/* Don't send message to idmap child. We've already
done so above. */
- if (!child->domain || (child == idmap_child())) {
+ if (!child->domain || winbindd_internal_child(child)) {
continue;
}
@@ -655,8 +655,8 @@ void winbind_msg_online(struct messaging_context *msg_ctx,
}
for (child = children; child != NULL; child = child->next) {
- /* Don't send message to idmap child. */
- if (!child->domain || (child == idmap_child())) {
+ /* Don't send message to internal childs. */
+ if (!child->domain || winbindd_internal_child(child)) {
continue;
}
@@ -579,9 +579,9 @@ void winbind_msg_offline(struct messaging_context *msg_ctx,
}
for (child = children; child != NULL; child = child->next) {
- /* Don't send message to idmap child. We've already
+ /* Don't send message to internal childs. We've already
done so above. */